Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Deck ¶
type Deck []Card
func CombineDecks ¶ added in v0.2.0
func NewDeckFromCards ¶ added in v0.2.0
func (*Deck) DealFromBottom ¶ added in v0.2.0
type Suit ¶
type Suit int
func (Suit) LaTeX ¶
LaTeX returns the LaTeX command that will print the symbol for this card's suit. For the standard deck of playing cards, the commands should work fine in base LaTeX. For the Tarot suits, however, the following packages will need to be included:
- esrelation
- fourier
- linearb
- MnSymbol
Click to show internal directories.
Click to hide internal directories.